# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from aioketraapi.api_client import ApiClient
from aioketraapi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SceneOperationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def root_get(self, **kwargs):  # noqa: E501
        """Get keypads and groups  (and scenes in API schema 4 or later)  # noqa: E501

        Gets all keypads and groups in the installation.  Added in hub firmware version 1.14 (API schema 3).   Scenes are also returned in API schema 4.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.root_get(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse200
        """
        kwargs['_return_http_data_only'] = True
        return self.root_get_with_http_info(**kwargs)  # noqa: E501

    def root_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get keypads and groups  (and scenes in API schema 4 or later)  # noqa: E501

        Gets all keypads and groups in the installation.  Added in hub firmware version 1.14 (API schema 3).   Scenes are also returned in API schema 4.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.root_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse200, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method root_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def scenes_get(self, **kwargs):  # noqa: E501
        """Get Scenes  # noqa: E501

        (New in API schema 4)  Gets the list of defined Scenes.   A scene is a predefined state (or states) for one or more groups of lights.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_get(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2005
        """
        kwargs['_return_http_data_only'] = True
        return self.scenes_get_with_http_info(**kwargs)  # noqa: E501

    def scenes_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Scenes  # noqa: E501

        (New in API schema 4)  Gets the list of defined Scenes.   A scene is a predefined state (or states) for one or more groups of lights.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2005, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scenes_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/Scenes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2005',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def scenes_scene_id_activate_post(self, scene_id, **kwargs):  # noqa: E501
        """Activates a scene  # noqa: E501

        (New in API schema 4)  Activates a Ketra scene specified by {scene-id}.   If a group is specified, the scene will be activated only for that group (and its subgroups).  If no group is specified, the scene will be activated for all groups for which the scene is defined.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_scene_id_activate_post(scene_id, async_req=True)
        >>> result = thread.get()

        :param scene_id: The scene's unique identifier (uuid) (required)
        :type scene_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param group: Specifies the parent group for which the scene should be activated
        :type group: str
        :param level: Specifies the master brightness level (from 0 to 65535) at which the scene should be activated.  If this parameter is omitted, the scene will be activated at the maximum level (65535).
        :type level: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2007
        """
        kwargs['_return_http_data_only'] = True
        return self.scenes_scene_id_activate_post_with_http_info(scene_id, **kwargs)  # noqa: E501

    def scenes_scene_id_activate_post_with_http_info(self, scene_id, **kwargs):  # noqa: E501
        """Activates a scene  # noqa: E501

        (New in API schema 4)  Activates a Ketra scene specified by {scene-id}.   If a group is specified, the scene will be activated only for that group (and its subgroups).  If no group is specified, the scene will be activated for all groups for which the scene is defined.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_scene_id_activate_post_with_http_info(scene_id, async_req=True)
        >>> result = thread.get()

        :param scene_id: The scene's unique identifier (uuid) (required)
        :type scene_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param group: Specifies the parent group for which the scene should be activated
        :type group: str
        :param level: Specifies the master brightness level (from 0 to 65535) at which the scene should be activated.  If this parameter is omitted, the scene will be activated at the maximum level (65535).
        :type level: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2007, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'scene_id',
            'basicauthuser',
            'basicauthpassword',
            'group',
            'level'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scenes_scene_id_activate_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scene_id' is set
        if self.api_client.client_side_validation and ('scene_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scene_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scene_id` when calling `scenes_scene_id_activate_post`")  # noqa: E501

        if self.api_client.client_side_validation and 'level' in local_var_params and local_var_params['level'] > 65535:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `level` when calling `scenes_scene_id_activate_post`, must be a value less than or equal to `65535`")  # noqa: E501
        if self.api_client.client_side_validation and 'level' in local_var_params and local_var_params['level'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `level` when calling `scenes_scene_id_activate_post`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'scene_id' in local_var_params:
            path_params['scene-id'] = local_var_params['scene_id']  # noqa: E501

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501
        if 'group' in local_var_params and local_var_params['group'] is not None:  # noqa: E501
            query_params.append(('group', local_var_params['group']))  # noqa: E501
        if 'level' in local_var_params and local_var_params['level'] is not None:  # noqa: E501
            query_params.append(('level', local_var_params['level']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/Scenes/{scene-id}/Activate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2007',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def scenes_scene_id_get(self, scene_id, **kwargs):  # noqa: E501
        """Gets a single scene  # noqa: E501

        (New in API schema 4) Gets a Ketra scene specified by {scene-id}.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_scene_id_get(scene_id, async_req=True)
        >>> result = thread.get()

        :param scene_id: The scene's unique identifier (uuid) (required)
        :type scene_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2006
        """
        kwargs['_return_http_data_only'] = True
        return self.scenes_scene_id_get_with_http_info(scene_id, **kwargs)  # noqa: E501

    def scenes_scene_id_get_with_http_info(self, scene_id, **kwargs):  # noqa: E501
        """Gets a single scene  # noqa: E501

        (New in API schema 4) Gets a Ketra scene specified by {scene-id}.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.scenes_scene_id_get_with_http_info(scene_id, async_req=True)
        >>> result = thread.get()

        :param scene_id: The scene's unique identifier (uuid) (required)
        :type scene_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2006, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'scene_id',
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scenes_scene_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scene_id' is set
        if self.api_client.client_side_validation and ('scene_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scene_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scene_id` when calling `scenes_scene_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scene_id' in local_var_params:
            path_params['scene-id'] = local_var_params['scene_id']  # noqa: E501

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/Scenes/{scene-id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2006',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from aioketraapi.api_client import ApiClient
from aioketraapi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class HubOperationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def hub_get(self, **kwargs):  # noqa: E501
        """Gets properties of the hub  # noqa: E501

        Gets informational and diagnostic properties of the hub.  Added in hub firmware version 1.14 (API schema 3).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.hub_get(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2004
        """
        kwargs['_return_http_data_only'] = True
        return self.hub_get_with_http_info(**kwargs)  # noqa: E501

    def hub_get_with_http_info(self, **kwargs):  # noqa: E501
        """Gets properties of the hub  # noqa: E501

        Gets informational and diagnostic properties of the hub.  Added in hub firmware version 1.14 (API schema 3).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.hub_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2004, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hub_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/Hub', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

# flake8: noqa

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from aioketraapi.api.group_operations_api import GroupOperationsApi
from aioketraapi.api.hub_operations_api import HubOperationsApi
from aioketraapi.api.keypad_operations_api import KeypadOperationsApi
from aioketraapi.api.lamp_operations_api import LampOperationsApi
from aioketraapi.api.scene_operations_api import SceneOperationsApi

# import ApiClient
from aioketraapi.api_client import ApiClient
from aioketraapi.configuration import Configuration
from aioketraapi.exceptions import OpenApiException
from aioketraapi.exceptions import ApiTypeError
from aioketraapi.exceptions import ApiValueError
from aioketraapi.exceptions import ApiKeyError
from aioketraapi.exceptions import ApiAttributeError
from aioketraapi.exceptions import ApiException
# import models into sdk package
from aioketraapi.models.button import Button
from aioketraapi.models.button_change import ButtonChange
from aioketraapi.models.button_change_all_of import ButtonChangeAllOf
from aioketraapi.models.button_change_notification import ButtonChangeNotification
from aioketraapi.models.group import Group
from aioketraapi.models.group_state_change import GroupStateChange
from aioketraapi.models.group_state_change_all_of import GroupStateChangeAllOf
from aioketraapi.models.hub_ready import HubReady
from aioketraapi.models.hub_ready_all_of import HubReadyAllOf
from aioketraapi.models.inline_response200 import InlineResponse200
from aioketraapi.models.inline_response2001 import InlineResponse2001
from aioketraapi.models.inline_response20010 import InlineResponse20010
from aioketraapi.models.inline_response20011 import InlineResponse20011
from aioketraapi.models.inline_response20012 import InlineResponse20012
from aioketraapi.models.inline_response20013 import InlineResponse20013
from aioketraapi.models.inline_response20014 import InlineResponse20014
from aioketraapi.models.inline_response2002 import InlineResponse2002
from aioketraapi.models.inline_response2003 import InlineResponse2003
from aioketraapi.models.inline_response2004 import InlineResponse2004
from aioketraapi.models.inline_response2004_content import InlineResponse2004Content
from aioketraapi.models.inline_response2005 import InlineResponse2005
from aioketraapi.models.inline_response2006 import InlineResponse2006
from aioketraapi.models.inline_response2007 import InlineResponse2007
from aioketraapi.models.inline_response2008 import InlineResponse2008
from aioketraapi.models.inline_response2009 import InlineResponse2009
from aioketraapi.models.inline_response200_content import InlineResponse200Content
from aioketraapi.models.keypad import Keypad
from aioketraapi.models.lamp import Lamp
from aioketraapi.models.lamp_state import LampState
from aioketraapi.models.lamp_state_all_of import LampStateAllOf
from aioketraapi.models.lamp_state_parameters import LampStateParameters
from aioketraapi.models.level import Level
from aioketraapi.models.publish_begin import PublishBegin
from aioketraapi.models.publish_begin_all_of import PublishBeginAllOf
from aioketraapi.models.scene import Scene
from aioketraapi.models.websocket_v2_notification import WebsocketV2Notification




# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from aioketraapi.api_client import ApiClient
from aioketraapi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LampOperationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def lamps_get(self, **kwargs):  # noqa: E501
        """Gets lamps in the installation  # noqa: E501

        placeholder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_get(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2001
        """
        kwargs['_return_http_data_only'] = True
        return self.lamps_get_with_http_info(**kwargs)  # noqa: E501

    def lamps_get_with_http_info(self, **kwargs):  # noqa: E501
        """Gets lamps in the installation  # noqa: E501

        placeholder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2001, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lamps_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/lamps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def lamps_lamp_id_get(self, lamp_id, **kwargs):  # noqa: E501
        """Gets a lamp by its id  # noqa: E501

        placeholder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_lamp_id_get(lamp_id, async_req=True)
        >>> result = thread.get()

        :param lamp_id: The lamp's unique identifier (uuid) (required)
        :type lamp_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2002
        """
        kwargs['_return_http_data_only'] = True
        return self.lamps_lamp_id_get_with_http_info(lamp_id, **kwargs)  # noqa: E501

    def lamps_lamp_id_get_with_http_info(self, lamp_id, **kwargs):  # noqa: E501
        """Gets a lamp by its id  # noqa: E501

        placeholder  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_lamp_id_get_with_http_info(lamp_id, async_req=True)
        >>> result = thread.get()

        :param lamp_id: The lamp's unique identifier (uuid) (required)
        :type lamp_id: str
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2002, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'lamp_id',
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lamps_lamp_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'lamp_id' is set
        if self.api_client.client_side_validation and ('lamp_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['lamp_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `lamp_id` when calling `lamps_lamp_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lamp_id' in local_var_params:
            path_params['lamp-id'] = local_var_params['lamp_id']  # noqa: E501

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/lamps/{lamp-id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def lamps_lamp_id_state_put(self, lamp_id, lamp_state, **kwargs):  # noqa: E501
        """sets a lamp state  # noqa: E501

        sets a lamp state  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_lamp_id_state_put(lamp_id, lamp_state, async_req=True)
        >>> result = thread.get()

        :param lamp_id: The lamp's unique identifier (uuid) (required)
        :type lamp_id: str
        :param lamp_state: Color settings to apply to the lamp (required)
        :type lamp_state: LampState
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: InlineResponse2003
        """
        kwargs['_return_http_data_only'] = True
        return self.lamps_lamp_id_state_put_with_http_info(lamp_id, lamp_state, **kwargs)  # noqa: E501

    def lamps_lamp_id_state_put_with_http_info(self, lamp_id, lamp_state, **kwargs):  # noqa: E501
        """sets a lamp state  # noqa: E501

        sets a lamp state  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.lamps_lamp_id_state_put_with_http_info(lamp_id, lamp_state, async_req=True)
        >>> result = thread.get()

        :param lamp_id: The lamp's unique identifier (uuid) (required)
        :type lamp_id: str
        :param lamp_state: Color settings to apply to the lamp (required)
        :type lamp_state: LampState
        :param basicauthuser: Username to use in place of username in basic authentication header.  For a secure installation, this value is ignored but still must be supplied unless a basic authentication header is sent with the request.
        :type basicauthuser: str
        :param basicauthpassword: Password to use in place of password in basic authentication header. For a secure installation, this should be an oauth token for a user with access to the installation.  If a basic authentication header is sent, this parameter is ignored.  If no basic authentication header is sent, this parameter as well as the basicauthuser parameter must be supplied if the hub is a member of a secure installation.
        :type basicauthpassword: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(InlineResponse2003, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'lamp_id',
            'lamp_state',
            'basicauthuser',
            'basicauthpassword'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lamps_lamp_id_state_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'lamp_id' is set
        if self.api_client.client_side_validation and ('lamp_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['lamp_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `lamp_id` when calling `lamps_lamp_id_state_put`")  # noqa: E501
        # verify the required parameter 'lamp_state' is set
        if self.api_client.client_side_validation and ('lamp_state' not in local_var_params or  # noqa: E501
                                                        local_var_params['lamp_state'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `lamp_state` when calling `lamps_lamp_id_state_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'lamp_id' in local_var_params:
            path_params['lamp-id'] = local_var_params['lamp_id']  # noqa: E501

        query_params = []
        if 'basicauthuser' in local_var_params and local_var_params['basicauthuser'] is not None:  # noqa: E501
            query_params.append(('basicauthuser', local_var_params['basicauthuser']))  # noqa: E501
        if 'basicauthpassword' in local_var_params and local_var_params['basicauthpassword'] is not None:  # noqa: E501
            query_params.append(('basicauthpassword', local_var_params['basicauthpassword']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'lamp_state' in local_var_params:
            body_params = local_var_params['lamp_state']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/lamps/{lamp-id}/state', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aioketraapi
from aioketraapi.api.keypad_operations_api import KeypadOperationsApi  # noqa: E501
from aioketraapi.rest import ApiException


class TestKeypadOperationsApi(unittest.TestCase):
    """KeypadOperationsApi unit test stubs"""

    def setUp(self):
        self.api = aioketraapi.api.keypad_operations_api.KeypadOperationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_button_post(self):
        """Test case for activate_button_post

        Activate a button  # noqa: E501
        """
        pass

    def test_deactivate_button_post(self):
        """Test case for deactivate_button_post

        Deactivate a button  # noqa: E501
        """
        pass

    def test_keypads_get(self):
        """Test case for keypads_get

        Get keypads  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_buttons_button_id_activate_post(self):
        """Test case for keypads_keypad_id_buttons_button_id_activate_post

        Activate a button  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_buttons_button_id_deactivate_post(self):
        """Test case for keypads_keypad_id_buttons_button_id_deactivate_post

        Deactivate a button  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_buttons_button_id_get(self):
        """Test case for keypads_keypad_id_buttons_button_id_get

        Gets the specified button for a specified keypad  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_buttons_button_id_push_button_post(self):
        """Test case for keypads_keypad_id_buttons_button_id_push_button_post

        Pushes a button  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_buttons_get(self):
        """Test case for keypads_keypad_id_buttons_get

        Gets the buttons for a keypad  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_get(self):
        """Test case for keypads_keypad_id_get

        Gets a single keypad  # noqa: E501
        """
        pass

    def test_keypads_keypad_id_set_level_post(self):
        """Test case for keypads_keypad_id_set_level_post

        sets the master intensity level for a single keypad  # noqa: E501
        """
        pass

    def test_push_button_post(self):
        """Test case for push_button_post

        Deactivate a button  # noqa: E501
        """
        pass

    def test_root_get(self):
        """Test case for root_get

        Get keypads and groups  (and scenes in API schema 4 or later)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aioketraapi
from aioketraapi.api.lamp_operations_api import LampOperationsApi  # noqa: E501
from aioketraapi.rest import ApiException


class TestLampOperationsApi(unittest.TestCase):
    """LampOperationsApi unit test stubs"""

    def setUp(self):
        self.api = aioketraapi.api.lamp_operations_api.LampOperationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_lamps_get(self):
        """Test case for lamps_get

        Gets lamps in the installation  # noqa: E501
        """
        pass

    def test_lamps_lamp_id_get(self):
        """Test case for lamps_lamp_id_get

        Gets a lamp by its id  # noqa: E501
        """
        pass

    def test_lamps_lamp_id_state_put(self):
        """Test case for lamps_lamp_id_state_put

        sets a lamp state  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import aiohttp
import json

class OAuthTokenResponse:
    def __init__(self, access_token=None, refresh_token=None, expires_at=None, **_):
        if access_token is None:
            raise ValueError("oauth_token must not be None")
        self.access_token = access_token
        self.refresh_token = refresh_token
        self.expires_at = expires_at

    def write_to_file(self, fn):
        with open(fn, 'w') as f:
            obj_to_write = {**self.__dict__}
            for key in list(obj_to_write.keys()):
                if obj_to_write[key] is None:
                    obj_to_write.pop(key)
            f.write(json.dumps(obj_to_write))

    @classmethod
    def load_from_file(cls, fn):
        with open(fn) as f:
            json_obj = json.load(f)
            return cls(**json_obj)


    @classmethod
    async def request_token(cls, client_id, client_secret, username, password, loop=None):
        url = 'https://my.goketra.com/oauth/token'
        request_data = {"username": username, "password": password,
                        "grant_type": "password", "client_id": client_id,
                        "client_secret": client_secret}
        async with aiohttp.ClientSession(loop=loop) as session:
            async with session.post(url, json=request_data) as response:
                if response.status == 200:
                    content = await response.json()
                    return OAuthTokenResponse(**content)




# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aioketraapi.configuration import Configuration


class InlineResponse20013(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'success': 'bool',
        'error': 'str',
        'content': 'Group'
    }

    attribute_map = {
        'success': 'Success',
        'error': 'Error',
        'content': 'Content'
    }

    def __init__(self, success=None, error=None, content=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse20013 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._success = None
        self._error = None
        self._content = None
        self.discriminator = None

        if success is not None:
            self.success = success
        if error is not None:
            self.error = error
        if content is not None:
            self.content = content

    @property
    def success(self):
        """Gets the success of this InlineResponse20013.  # noqa: E501

        true if the transaction was successful, false if an error occurred  # noqa: E501

        :return: The success of this InlineResponse20013.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this InlineResponse20013.

        true if the transaction was successful, false if an error occurred  # noqa: E501

        :param success: The success of this InlineResponse20013.  # noqa: E501
        :type success: bool
        """

        self._success = success

    @property
    def error(self):
        """Gets the error of this InlineResponse20013.  # noqa: E501

        error message  # noqa: E501

        :return: The error of this InlineResponse20013.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this InlineResponse20013.

        error message  # noqa: E501

        :param error: The error of this InlineResponse20013.  # noqa: E501
        :type error: str
        """

        self._error = error

    @property
    def content(self):
        """Gets the content of this InlineResponse20013.  # noqa: E501


        :return: The content of this InlineResponse20013.  # noqa: E501
        :rtype: Group
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this InlineResponse20013.


        :param content: The content of this InlineResponse20013.  # noqa: E501
        :type content: Group
        """

        self._content = content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20013):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20013):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aioketraapi
from aioketraapi.api.hub_operations_api import HubOperationsApi  # noqa: E501
from aioketraapi.rest import ApiException


class TestHubOperationsApi(unittest.TestCase):
    """HubOperationsApi unit test stubs"""

    def setUp(self):
        self.api = aioketraapi.api.hub_operations_api.HubOperationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_hub_get(self):
        """Test case for hub_get

        Gets properties of the hub  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aioketraapi.configuration import Configuration


class LampStateAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'transition_time': 'int',
        'updated_at': 'str',
        'transition_complete': 'bool',
        'active_shows': 'list[int]',
        'start_state': 'LampStateParameters'
    }

    attribute_map = {
        'transition_time': 'TransitionTime',
        'updated_at': 'UpdatedAt',
        'transition_complete': 'TransitionComplete',
        'active_shows': 'ActiveShows',
        'start_state': 'StartState'
    }

    def __init__(self, transition_time=None, updated_at=None, transition_complete=None, active_shows=None, start_state=None, local_vars_configuration=None):  # noqa: E501
        """LampStateAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._transition_time = None
        self._updated_at = None
        self._transition_complete = None
        self._active_shows = None
        self._start_state = None
        self.discriminator = None

        if transition_time is not None:
            self.transition_time = transition_time
        if updated_at is not None:
            self.updated_at = updated_at
        if transition_complete is not None:
            self.transition_complete = transition_complete
        if active_shows is not None:
            self.active_shows = active_shows
        if start_state is not None:
            self.start_state = start_state

    @property
    def transition_time(self):
        """Gets the transition_time of this LampStateAllOf.  # noqa: E501

        transition time, in ms.  (Required)  # noqa: E501

        :return: The transition_time of this LampStateAllOf.  # noqa: E501
        :rtype: int
        """
        return self._transition_time

    @transition_time.setter
    def transition_time(self, transition_time):
        """Sets the transition_time of this LampStateAllOf.

        transition time, in ms.  (Required)  # noqa: E501

        :param transition_time: The transition_time of this LampStateAllOf.  # noqa: E501
        :type transition_time: int
        """
        if (self.local_vars_configuration.client_side_validation and
                transition_time is not None and transition_time > 6553500):  # noqa: E501
            raise ValueError("Invalid value for `transition_time`, must be a value less than or equal to `6553500`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                transition_time is not None and transition_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `transition_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._transition_time = transition_time

    @property
    def updated_at(self):
        """Gets the updated_at of this LampStateAllOf.  # noqa: E501

        the time at which the group was last updated.  New for API schema 4.  # noqa: E501

        :return: The updated_at of this LampStateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this LampStateAllOf.

        the time at which the group was last updated.  New for API schema 4.  # noqa: E501

        :param updated_at: The updated_at of this LampStateAllOf.  # noqa: E501
        :type updated_at: str
        """

        self._updated_at = updated_at

    @property
    def transition_complete(self):
        """Gets the transition_complete of this LampStateAllOf.  # noqa: E501

        returns true if the lamp is finished transitioning to the last updated color.  New for API schema 4.  # noqa: E501

        :return: The transition_complete of this LampStateAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._transition_complete

    @transition_complete.setter
    def transition_complete(self, transition_complete):
        """Sets the transition_complete of this LampStateAllOf.

        returns true if the lamp is finished transitioning to the last updated color.  New for API schema 4.  # noqa: E501

        :param transition_complete: The transition_complete of this LampStateAllOf.  # noqa: E501
        :type transition_complete: bool
        """

        self._transition_complete = transition_complete

    @property
    def active_shows(self):
        """Gets the active_shows of this LampStateAllOf.  # noqa: E501

        indicates the show groups that are currently active for the group.  New for API schema 4.  # noqa: E501

        :return: The active_shows of this LampStateAllOf.  # noqa: E501
        :rtype: list[int]
        """
        return self._active_shows

    @active_shows.setter
    def active_shows(self, active_shows):
        """Sets the active_shows of this LampStateAllOf.

        indicates the show groups that are currently active for the group.  New for API schema 4.  # noqa: E501

        :param active_shows: The active_shows of this LampStateAllOf.  # noqa: E501
        :type active_shows: list[int]
        """

        self._active_shows = active_shows

    @property
    def start_state(self):
        """Gets the start_state of this LampStateAllOf.  # noqa: E501


        :return: The start_state of this LampStateAllOf.  # noqa: E501
        :rtype: LampStateParameters
        """
        return self._start_state

    @start_state.setter
    def start_state(self, start_state):
        """Sets the start_state of this LampStateAllOf.


        :param start_state: The start_state of this LampStateAllOf.  # noqa: E501
        :type start_state: LampStateParameters
        """

        self._start_state = start_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LampStateAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LampStateAllOf):
            return True

        return self.to_dict() != other.to_dict()



from aioketraapi.models.group import Group as GroupModel
from aioketraapi.models.lamp_state import LampState as LampStateModel
from aioketraapi.api.group_operations_api import GroupOperationsApi



class Group(GroupModel):
    def __init__(self, group_model: GroupModel, hub):
        super().__init__(**group_model.to_dict())
        self.state = group_model.state
        self.hub = hub

    def update_state_from_model(self, lamp_state: LampStateModel):
        self.state = lamp_state

    async def update_state(self):
        async with self.hub.create_client_session() as api_client:
            updated_group = await GroupOperationsApi(api_client).groups_group_id_state_get(self.id)
            self.update_state_from_model(updated_group.content)

    async def set_state(self, lamp_state: LampStateModel, **kwargs):
        async with self.hub.create_client_session() as api_client:
            updated_group = await GroupOperationsApi(api_client).groups_group_id_state_put(self.id, lamp_state, **kwargs)
            self.update_state_from_model(updated_group.content)








# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.inline_response20013 import InlineResponse20013  # noqa: E501
from aioketraapi.rest import ApiException

class TestInlineResponse20013(unittest.TestCase):
    """InlineResponse20013 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse20013
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.inline_response20013.InlineResponse20013()  # noqa: E501
        if include_optional :
            return InlineResponse20013(
                success = True, 
                error = '0', 
                content = aioketraapi.models.group.Group(
                    id = '0', 
                    name = '0', 
                    child_groups = [
                        '0'
                        ], 
                    parent_groups = [
                        '0'
                        ], 
                    address = 56, 
                    state = aioketraapi.models.lamp_state.LampState(), )
            )
        else :
            return InlineResponse20013(
        )

    def testInlineResponse20013(self):
        """Test InlineResponse20013"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.button_change import ButtonChange  # noqa: E501
from aioketraapi.rest import ApiException

class TestButtonChange(unittest.TestCase):
    """ButtonChange unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ButtonChange
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.button_change.ButtonChange()  # noqa: E501
        if include_optional :
            return ButtonChange(
                notification_type = 'ButtonChange', 
                time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                contents = aioketraapi.models.button_change_notification.ButtonChangeNotification(
                    button_id = '0', 
                    client_id = '0', 
                    level = 56, 
                    activated = True, 
                    time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else :
            return ButtonChange(
                notification_type = 'ButtonChange',
                time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                contents = aioketraapi.models.button_change_notification.ButtonChangeNotification(
                    button_id = '0', 
                    client_id = '0', 
                    level = 56, 
                    activated = True, 
                    time_utc = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )

    def testButtonChange(self):
        """Test ButtonChange"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from aioketraapi.models.button import Button
from aioketraapi.models.button_change import ButtonChange
from aioketraapi.models.button_change_all_of import ButtonChangeAllOf
from aioketraapi.models.button_change_notification import ButtonChangeNotification
from aioketraapi.models.group import Group
from aioketraapi.models.group_state_change import GroupStateChange
from aioketraapi.models.group_state_change_all_of import GroupStateChangeAllOf
from aioketraapi.models.hub_ready import HubReady
from aioketraapi.models.hub_ready_all_of import HubReadyAllOf
from aioketraapi.models.inline_response200 import InlineResponse200
from aioketraapi.models.inline_response2001 import InlineResponse2001
from aioketraapi.models.inline_response20010 import InlineResponse20010
from aioketraapi.models.inline_response20011 import InlineResponse20011
from aioketraapi.models.inline_response20012 import InlineResponse20012
from aioketraapi.models.inline_response20013 import InlineResponse20013
from aioketraapi.models.inline_response20014 import InlineResponse20014
from aioketraapi.models.inline_response2002 import InlineResponse2002
from aioketraapi.models.inline_response2003 import InlineResponse2003
from aioketraapi.models.inline_response2004 import InlineResponse2004
from aioketraapi.models.inline_response2004_content import InlineResponse2004Content
from aioketraapi.models.inline_response2005 import InlineResponse2005
from aioketraapi.models.inline_response2006 import InlineResponse2006
from aioketraapi.models.inline_response2007 import InlineResponse2007
from aioketraapi.models.inline_response2008 import InlineResponse2008
from aioketraapi.models.inline_response2009 import InlineResponse2009
from aioketraapi.models.inline_response200_content import InlineResponse200Content
from aioketraapi.models.keypad import Keypad
from aioketraapi.models.lamp import Lamp
from aioketraapi.models.lamp_state import LampState
from aioketraapi.models.lamp_state_all_of import LampStateAllOf
from aioketraapi.models.lamp_state_parameters import LampStateParameters
from aioketraapi.models.level import Level
from aioketraapi.models.publish_begin import PublishBegin
from aioketraapi.models.publish_begin_all_of import PublishBeginAllOf
from aioketraapi.models.scene import Scene
from aioketraapi.models.websocket_v2_notification import WebsocketV2Notification



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.inline_response2004 import InlineResponse2004  # noqa: E501
from aioketraapi.rest import ApiException

class TestInlineResponse2004(unittest.TestCase):
    """InlineResponse2004 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2004
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.inline_response2004.InlineResponse2004()  # noqa: E501
        if include_optional :
            return InlineResponse2004(
                success = True, 
                error = '0', 
                content = aioketraapi.models.inline_response_200_4_content.inline_response_200_4_Content(
                    api_schema = 56, 
                    cpu_version = '0', 
                    radio_version = '0', 
                    serial_number = '0', 
                    model_name = '0', 
                    id = '0', 
                    installation_id = '0', 
                    installation_name = '0', 
                    network_id = '0', 
                    name = '0', 
                    ethernet_mac = '0', 
                    i_pv4_address = '0', 
                    ethernet_link_status = [
                        True
                        ], 
                    up_time_seconds = 56, 
                    local_time = '0', 
                    utc_time = '0', 
                    last_reboot_reason = '0', 
                    has_internet_connectivity = True, 
                    last_time_update_was_successful = True, 
                    remote_connection_enabled = True, 
                    remote_connection_established = True, 
                    supports_zone_keypads = True, )
            )
        else :
            return InlineResponse2004(
        )

    def testInlineResponse2004(self):
        """Test InlineResponse2004"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from aioketraapi.models.keypad import Keypad as KeypadModel
from aioketraapi.models.button import Button as ButtonModel
from aioketraapi.models.level import Level as LevelModel
from aioketraapi.api.keypad_operations_api import KeypadOperationsApi



class Keypad(KeypadModel):
    def __init__(self, keypad_model: KeypadModel, hub):
        super().__init__(**keypad_model.to_dict())
        self.hub = hub
        self._buttons = []
        if keypad_model.buttons is not None:
            self._buttons = [KeypadButton(button, self, hub) for button in keypad_model.buttons]
        self._button_map = {}
        for button in self._buttons:
            self._button_map[button.id] = button

    async def update_state(self):
        async with self.hub.create_client_session() as api_client:
            updated_keypad = await KeypadOperationsApi(api_client).keypads_keypad_id_get(self.id)
            self.update_from_model(updated_keypad.content)

    def update_from_model(self, keypad_model: KeypadModel):
        for k,v in keypad_model.to_dict().items():
            setattr(self, k, v)
        if keypad_model.buttons is not None:
            for button in keypad_model.buttons:
                self._button_map[button.id].update_from_model(button)

    @property
    def buttons(self):
        return self._buttons

    @buttons.setter
    def buttons(self, buttons):
        pass


class KeypadButton(ButtonModel):
    def __init__(self, button_model: ButtonModel, keypad: Keypad, hub):
        super().__init__(**button_model.to_dict())
        self.keypad = keypad
        self.hub = hub

    def update_from_model(self, button_model: ButtonModel):
        for k,v in button_model.to_dict().items():
            setattr(self, k, v)

    async def activate(self, level=65535):
        async with self.hub.create_client_session() as api_client:
            updated_keypad = await KeypadOperationsApi(api_client).keypads_keypad_id_buttons_button_id_activate_post(
                self.keypad.id,
                self.id,
                LevelModel(level))
            self.keypad.update_from_model(updated_keypad.content)

    async def deactivate(self):
        async with self.hub.create_client_session() as api_client:
            updated_keypad = await KeypadOperationsApi(api_client).keypads_keypad_id_buttons_button_id_deactivate_post(
                self.keypad.id,
                self.id,
                LevelModel())
            self.keypad.update_from_model(updated_keypad.content)

    @property
    def scene_name(self):
        _, _, kp_name = self.keypad.name.rpartition('/')
        return f"{kp_name} {self.name}"







def model_to_json(model) -> dict:
    model_json = model.to_dict()
    for attr in list(model_json.keys()):
        if attr in model.attribute_map:
            model_json[model.attribute_map[attr]] = model_json.pop(attr)
    return model_json


# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aioketraapi
from aioketraapi.models.keypad import Keypad  # noqa: E501
from aioketraapi.rest import ApiException

class TestKeypad(unittest.TestCase):
    """Keypad unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Keypad
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aioketraapi.models.keypad.Keypad()  # noqa: E501
        if include_optional :
            return Keypad(
                id = '0', 
                is_virtual = True, 
                level = 56, 
                name = '0', 
                serial_number = '0', 
                buttons = [
                    aioketraapi.models.button.Button(
                        active = True, 
                        id = '0', 
                        level = 56, 
                        name = '0', 
                        position = 56, 
                        is_power_button = True, 
                        scene_is_modified = True, )
                    ]
            )
        else :
            return Keypad(
        )

    def testKeypad(self):
        """Test Keypad"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aioketraapi.configuration import Configuration


class Button(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'id': 'str',
        'level': 'int',
        'name': 'str',
        'position': 'int',
        'is_power_button': 'bool',
        'scene_is_modified': 'bool'
    }

    attribute_map = {
        'active': 'Active',
        'id': 'Id',
        'level': 'Level',
        'name': 'Name',
        'position': 'Position',
        'is_power_button': 'IsPowerButton',
        'scene_is_modified': 'SceneIsModified'
    }

    def __init__(self, active=None, id=None, level=None, name=None, position=None, is_power_button=None, scene_is_modified=None, local_vars_configuration=None):  # noqa: E501
        """Button - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._id = None
        self._level = None
        self._name = None
        self._position = None
        self._is_power_button = None
        self._scene_is_modified = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if id is not None:
            self.id = id
        if level is not None:
            self.level = level
        if name is not None:
            self.name = name
        if position is not None:
            self.position = position
        if is_power_button is not None:
            self.is_power_button = is_power_button
        if scene_is_modified is not None:
            self.scene_is_modified = scene_is_modified

    @property
    def active(self):
        """Gets the active of this Button.  # noqa: E501

        is the button active?  # noqa: E501

        :return: The active of this Button.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Button.

        is the button active?  # noqa: E501

        :param active: The active of this Button.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def id(self):
        """Gets the id of this Button.  # noqa: E501

        Id of the button  # noqa: E501

        :return: The id of this Button.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Button.

        Id of the button  # noqa: E501

        :param id: The id of this Button.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def level(self):
        """Gets the level of this Button.  # noqa: E501

        intensity level of the button's scene or show  # noqa: E501

        :return: The level of this Button.  # noqa: E501
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this Button.

        intensity level of the button's scene or show  # noqa: E501

        :param level: The level of this Button.  # noqa: E501
        :type level: int
        """

        self._level = level

    @property
    def name(self):
        """Gets the name of this Button.  # noqa: E501

        Name of the button  # noqa: E501

        :return: The name of this Button.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Button.

        Name of the button  # noqa: E501

        :param name: The name of this Button.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def position(self):
        """Gets the position of this Button.  # noqa: E501

        Zero-based position of the button on the keypad  # noqa: E501

        :return: The position of this Button.  # noqa: E501
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Button.

        Zero-based position of the button on the keypad  # noqa: E501

        :param position: The position of this Button.  # noqa: E501
        :type position: int
        """

        self._position = position

    @property
    def is_power_button(self):
        """Gets the is_power_button of this Button.  # noqa: E501

        is this button a power button?  (added in firmware version 1.12)  # noqa: E501

        :return: The is_power_button of this Button.  # noqa: E501
        :rtype: bool
        """
        return self._is_power_button

    @is_power_button.setter
    def is_power_button(self, is_power_button):
        """Sets the is_power_button of this Button.

        is this button a power button?  (added in firmware version 1.12)  # noqa: E501

        :param is_power_button: The is_power_button of this Button.  # noqa: E501
        :type is_power_button: bool
        """

        self._is_power_button = is_power_button

    @property
    def scene_is_modified(self):
        """Gets the scene_is_modified of this Button.  # noqa: E501

        is the scene modified by a child keypad?   (added in firmware version 1.12)  # noqa: E501

        :return: The scene_is_modified of this Button.  # noqa: E501
        :rtype: bool
        """
        return self._scene_is_modified

    @scene_is_modified.setter
    def scene_is_modified(self, scene_is_modified):
        """Sets the scene_is_modified of this Button.

        is the scene modified by a child keypad?   (added in firmware version 1.12)  # noqa: E501

        :param scene_is_modified: The scene_is_modified of this Button.  # noqa: E501
        :type scene_is_modified: bool
        """

        self._scene_is_modified = scene_is_modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Button):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Button):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Ketra Lighting API

    Control your Ketra lights  # noqa: E501

    The version of the OpenAPI document: 1.4.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aioketraapi.configuration import Configuration


class InlineResponse2004Content(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_schema': 'int',
        'cpu_version': 'str',
        'radio_version': 'str',
        'serial_number': 'str',
        'model_name': 'str',
        'id': 'str',
        'installation_id': 'str',
        'installation_name': 'str',
        'network_id': 'str',
        'name': 'str',
        'ethernet_mac': 'str',
        'i_pv4_address': 'str',
        'ethernet_link_status': 'list[bool]',
        'up_time_seconds': 'int',
        'local_time': 'str',
        'utc_time': 'str',
        'last_reboot_reason': 'str',
        'has_internet_connectivity': 'bool',
        'last_time_update_was_successful': 'bool',
        'remote_connection_enabled': 'bool',
        'remote_connection_established': 'bool',
        'supports_zone_keypads': 'bool'
    }

    attribute_map = {
        'api_schema': 'APISchema',
        'cpu_version': 'CPUVersion',
        'radio_version': 'RadioVersion',
        'serial_number': 'SerialNumber',
        'model_name': 'ModelName',
        'id': 'Id',
        'installation_id': 'InstallationId',
        'installation_name': 'InstallationName',
        'network_id': 'NetworkId',
        'name': 'Name',
        'ethernet_mac': 'EthernetMAC',
        'i_pv4_address': 'IPv4Address',
        'ethernet_link_status': 'EthernetLinkStatus',
        'up_time_seconds': 'UpTimeSeconds',
        'local_time': 'LocalTime',
        'utc_time': 'UTCTime',
        'last_reboot_reason': 'LastRebootReason',
        'has_internet_connectivity': 'HasInternetConnectivity',
        'last_time_update_was_successful': 'LastTimeUpdateWasSuccessful',
        'remote_connection_enabled': 'RemoteConnectionEnabled',
        'remote_connection_established': 'RemoteConnectionEstablished',
        'supports_zone_keypads': 'SupportsZoneKeypads'
    }

    def __init__(self, api_schema=None, cpu_version=None, radio_version=None, serial_number=None, model_name=None, id=None, installation_id=None, installation_name=None, network_id=None, name=None, ethernet_mac=None, i_pv4_address=None, ethernet_link_status=None, up_time_seconds=None, local_time=None, utc_time=None, last_reboot_reason=None, has_internet_connectivity=None, last_time_update_was_successful=None, remote_connection_enabled=None, remote_connection_established=None, supports_zone_keypads=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse2004Content - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_schema = None
        self._cpu_version = None
        self._radio_version = None
        self._serial_number = None
        self._model_name = None
        self._id = None
        self._installation_id = None
        self._installation_name = None
        self._network_id = None
        self._name = None
        self._ethernet_mac = None
        self._i_pv4_address = None
        self._ethernet_link_status = None
        self._up_time_seconds = None
        self._local_time = None
        self._utc_time = None
        self._last_reboot_reason = None
        self._has_internet_connectivity = None
        self._last_time_update_was_successful = None
        self._remote_connection_enabled = None
        self._remote_connection_established = None
        self._supports_zone_keypads = None
        self.discriminator = None

        if api_schema is not None:
            self.api_schema = api_schema
        if cpu_version is not None:
            self.cpu_version = cpu_version
        if radio_version is not None:
            self.radio_version = radio_version
        if serial_number is not None:
            self.serial_number = serial_number
        if model_name is not None:
            self.model_name = model_name
        if id is not None:
            self.id = id
        if installation_id is not None:
            self.installation_id = installation_id
        if installation_name is not None:
            self.installation_name = installation_name
        if network_id is not None:
            self.network_id = network_id
        if name is not None:
            self.name = name
        if ethernet_mac is not None:
            self.ethernet_mac = ethernet_mac
        if i_pv4_address is not None:
            self.i_pv4_address = i_pv4_address
        if ethernet_link_status is not None:
            self.ethernet_link_status = ethernet_link_status
        if up_time_seconds is not None:
            self.up_time_seconds = up_time_seconds
        if local_time is not None:
            self.local_time = local_time
        if utc_time is not None:
            self.utc_time = utc_time
        if last_reboot_reason is not None:
            self.last_reboot_reason = last_reboot_reason
        if has_internet_connectivity is not None:
            self.has_internet_connectivity = has_internet_connectivity
        if last_time_update_was_successful is not None:
            self.last_time_update_was_successful = last_time_update_was_successful
        if remote_connection_enabled is not None:
            self.remote_connection_enabled = remote_connection_enabled
        if remote_connection_established is not None:
            self.remote_connection_established = remote_connection_established
        if supports_zone_keypads is not None:
            self.supports_zone_keypads = supports_zone_keypads

    @property
    def api_schema(self):
        """Gets the api_schema of this InlineResponse2004Content.  # noqa: E501

        API schema version supported by the hub's firmware  # noqa: E501

        :return: The api_schema of this InlineResponse2004Content.  # noqa: E501
        :rtype: int
        """
        return self._api_schema

    @api_schema.setter
    def api_schema(self, api_schema):
        """Sets the api_schema of this InlineResponse2004Content.

        API schema version supported by the hub's firmware  # noqa: E501

        :param api_schema: The api_schema of this InlineResponse2004Content.  # noqa: E501
        :type api_schema: int
        """

        self._api_schema = api_schema

    @property
    def cpu_version(self):
        """Gets the cpu_version of this InlineResponse2004Content.  # noqa: E501

        the version of the hub's CPU firmware  # noqa: E501

        :return: The cpu_version of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._cpu_version

    @cpu_version.setter
    def cpu_version(self, cpu_version):
        """Sets the cpu_version of this InlineResponse2004Content.

        the version of the hub's CPU firmware  # noqa: E501

        :param cpu_version: The cpu_version of this InlineResponse2004Content.  # noqa: E501
        :type cpu_version: str
        """

        self._cpu_version = cpu_version

    @property
    def radio_version(self):
        """Gets the radio_version of this InlineResponse2004Content.  # noqa: E501

        the version of the hub's radio firmware  # noqa: E501

        :return: The radio_version of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._radio_version

    @radio_version.setter
    def radio_version(self, radio_version):
        """Sets the radio_version of this InlineResponse2004Content.

        the version of the hub's radio firmware  # noqa: E501

        :param radio_version: The radio_version of this InlineResponse2004Content.  # noqa: E501
        :type radio_version: str
        """

        self._radio_version = radio_version

    @property
    def serial_number(self):
        """Gets the serial_number of this InlineResponse2004Content.  # noqa: E501

        the hub's serial number  # noqa: E501

        :return: The serial_number of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this InlineResponse2004Content.

        the hub's serial number  # noqa: E501

        :param serial_number: The serial_number of this InlineResponse2004Content.  # noqa: E501
        :type serial_number: str
        """

        self._serial_number = serial_number

    @property
    def model_name(self):
        """Gets the model_name of this InlineResponse2004Content.  # noqa: E501

        the model name of the hub  # noqa: E501

        :return: The model_name of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this InlineResponse2004Content.

        the model name of the hub  # noqa: E501

        :param model_name: The model_name of this InlineResponse2004Content.  # noqa: E501
        :type model_name: str
        """

        self._model_name = model_name

    @property
    def id(self):
        """Gets the id of this InlineResponse2004Content.  # noqa: E501

        the unique identifier of the hub  # noqa: E501

        :return: The id of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2004Content.

        the unique identifier of the hub  # noqa: E501

        :param id: The id of this InlineResponse2004Content.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def installation_id(self):
        """Gets the installation_id of this InlineResponse2004Content.  # noqa: E501

        the unique identifier of the hub's installation  # noqa: E501

        :return: The installation_id of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._installation_id

    @installation_id.setter
    def installation_id(self, installation_id):
        """Sets the installation_id of this InlineResponse2004Content.

        the unique identifier of the hub's installation  # noqa: E501

        :param installation_id: The installation_id of this InlineResponse2004Content.  # noqa: E501
        :type installation_id: str
        """

        self._installation_id = installation_id

    @property
    def installation_name(self):
        """Gets the installation_name of this InlineResponse2004Content.  # noqa: E501

        the name of the hub's installation  # noqa: E501

        :return: The installation_name of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._installation_name

    @installation_name.setter
    def installation_name(self, installation_name):
        """Sets the installation_name of this InlineResponse2004Content.

        the name of the hub's installation  # noqa: E501

        :param installation_name: The installation_name of this InlineResponse2004Content.  # noqa: E501
        :type installation_name: str
        """

        self._installation_name = installation_name

    @property
    def network_id(self):
        """Gets the network_id of this InlineResponse2004Content.  # noqa: E501

        the unique identifier of the hub's network  # noqa: E501

        :return: The network_id of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._network_id

    @network_id.setter
    def network_id(self, network_id):
        """Sets the network_id of this InlineResponse2004Content.

        the unique identifier of the hub's network  # noqa: E501

        :param network_id: The network_id of this InlineResponse2004Content.  # noqa: E501
        :type network_id: str
        """

        self._network_id = network_id

    @property
    def name(self):
        """Gets the name of this InlineResponse2004Content.  # noqa: E501

        the user-assigned name of the hub  # noqa: E501

        :return: The name of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2004Content.

        the user-assigned name of the hub  # noqa: E501

        :param name: The name of this InlineResponse2004Content.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def ethernet_mac(self):
        """Gets the ethernet_mac of this InlineResponse2004Content.  # noqa: E501

        the hub's ethernet MAC address  # noqa: E501

        :return: The ethernet_mac of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._ethernet_mac

    @ethernet_mac.setter
    def ethernet_mac(self, ethernet_mac):
        """Sets the ethernet_mac of this InlineResponse2004Content.

        the hub's ethernet MAC address  # noqa: E501

        :param ethernet_mac: The ethernet_mac of this InlineResponse2004Content.  # noqa: E501
        :type ethernet_mac: str
        """

        self._ethernet_mac = ethernet_mac

    @property
    def i_pv4_address(self):
        """Gets the i_pv4_address of this InlineResponse2004Content.  # noqa: E501

        the hub's IPv4 address  # noqa: E501

        :return: The i_pv4_address of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._i_pv4_address

    @i_pv4_address.setter
    def i_pv4_address(self, i_pv4_address):
        """Sets the i_pv4_address of this InlineResponse2004Content.

        the hub's IPv4 address  # noqa: E501

        :param i_pv4_address: The i_pv4_address of this InlineResponse2004Content.  # noqa: E501
        :type i_pv4_address: str
        """

        self._i_pv4_address = i_pv4_address

    @property
    def ethernet_link_status(self):
        """Gets the ethernet_link_status of this InlineResponse2004Content.  # noqa: E501

        the link status of the hub's ethernet ports. This is an array of length equal to the number of ethernet ports on the hub.  Each element will be true or false depending on whether a link was detected on the port or not.  # noqa: E501

        :return: The ethernet_link_status of this InlineResponse2004Content.  # noqa: E501
        :rtype: list[bool]
        """
        return self._ethernet_link_status

    @ethernet_link_status.setter
    def ethernet_link_status(self, ethernet_link_status):
        """Sets the ethernet_link_status of this InlineResponse2004Content.

        the link status of the hub's ethernet ports. This is an array of length equal to the number of ethernet ports on the hub.  Each element will be true or false depending on whether a link was detected on the port or not.  # noqa: E501

        :param ethernet_link_status: The ethernet_link_status of this InlineResponse2004Content.  # noqa: E501
        :type ethernet_link_status: list[bool]
        """

        self._ethernet_link_status = ethernet_link_status

    @property
    def up_time_seconds(self):
        """Gets the up_time_seconds of this InlineResponse2004Content.  # noqa: E501

        the number of seconds since last power cycle or reboot  # noqa: E501

        :return: The up_time_seconds of this InlineResponse2004Content.  # noqa: E501
        :rtype: int
        """
        return self._up_time_seconds

    @up_time_seconds.setter
    def up_time_seconds(self, up_time_seconds):
        """Sets the up_time_seconds of this InlineResponse2004Content.

        the number of seconds since last power cycle or reboot  # noqa: E501

        :param up_time_seconds: The up_time_seconds of this InlineResponse2004Content.  # noqa: E501
        :type up_time_seconds: int
        """

        self._up_time_seconds = up_time_seconds

    @property
    def local_time(self):
        """Gets the local_time of this InlineResponse2004Content.  # noqa: E501

        the local time  # noqa: E501

        :return: The local_time of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._local_time

    @local_time.setter
    def local_time(self, local_time):
        """Sets the local_time of this InlineResponse2004Content.

        the local time  # noqa: E501

        :param local_time: The local_time of this InlineResponse2004Content.  # noqa: E501
        :type local_time: str
        """

        self._local_time = local_time

    @property
    def utc_time(self):
        """Gets the utc_time of this InlineResponse2004Content.  # noqa: E501

        the time in UTC  # noqa: E501

        :return: The utc_time of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._utc_time

    @utc_time.setter
    def utc_time(self, utc_time):
        """Sets the utc_time of this InlineResponse2004Content.

        the time in UTC  # noqa: E501

        :param utc_time: The utc_time of this InlineResponse2004Content.  # noqa: E501
        :type utc_time: str
        """

        self._utc_time = utc_time

    @property
    def last_reboot_reason(self):
        """Gets the last_reboot_reason of this InlineResponse2004Content.  # noqa: E501

        the reason for the last reboot  # noqa: E501

        :return: The last_reboot_reason of this InlineResponse2004Content.  # noqa: E501
        :rtype: str
        """
        return self._last_reboot_reason

    @last_reboot_reason.setter
    def last_reboot_reason(self, last_reboot_reason):
        """Sets the last_reboot_reason of this InlineResponse2004Content.

        the reason for the last reboot  # noqa: E501

        :param last_reboot_reason: The last_reboot_reason of this InlineResponse2004Content.  # noqa: E501
        :type last_reboot_reason: str
        """

        self._last_reboot_reason = last_reboot_reason

    @property
    def has_internet_connectivity(self):
        """Gets the has_internet_connectivity of this InlineResponse2004Content.  # noqa: E501

        does the hub have internet access?  # noqa: E501

        :return: The has_internet_connectivity of this InlineResponse2004Content.  # noqa: E501
        :rtype: bool
        """
        return self._has_internet_connectivity

    @has_internet_connectivity.setter
    def has_internet_connectivity(self, has_internet_connectivity):
        """Sets the has_internet_connectivity of this InlineResponse2004Content.

        does the hub have internet access?  # noqa: E501

        :param has_internet_connectivity: The has_internet_connectivity of this InlineResponse2004Content.  # noqa: E501
        :type has_internet_connectivity: bool
        """

        self._has_internet_connectivity = has_internet_connectivity

    @property
    def last_time_update_was_successful(self):
        """Gets the last_time_update_was_successful of this InlineResponse2004Content.  # noqa: E501

        was the last time update successful?  # noqa: E501

        :return: The last_time_update_was_successful of this InlineResponse2004Content.  # noqa: E501
        :rtype: bool
        """
        return self._last_time_update_was_successful

    @last_time_update_was_successful.setter
    def last_time_update_was_successful(self, last_time_update_was_successful):
        """Sets the last_time_update_was_successful of this InlineResponse2004Content.

        was the last time update successful?  # noqa: E501

        :param last_time_update_was_successful: The last_time_update_was_successful of this InlineResponse2004Content.  # noqa: E501
        :type last_time_update_was_successful: bool
        """

        self._last_time_update_was_successful = last_time_update_was_successful

    @property
    def remote_connection_enabled(self):
        """Gets the remote_connection_enabled of this InlineResponse2004Content.  # noqa: E501

        is remote connectivity enabled?  # noqa: E501

        :return: The remote_connection_enabled of this InlineResponse2004Content.  # noqa: E501
        :rtype: bool
        """
        return self._remote_connection_enabled

    @remote_connection_enabled.setter
    def remote_connection_enabled(self, remote_connection_enabled):
        """Sets the remote_connection_enabled of this InlineResponse2004Content.

        is remote connectivity enabled?  # noqa: E501

        :param remote_connection_enabled: The remote_connection_enabled of this InlineResponse2004Content.  # noqa: E501
        :type remote_connection_enabled: bool
        """

        self._remote_connection_enabled = remote_connection_enabled

    @property
    def remote_connection_established(self):
        """Gets the remote_connection_established of this InlineResponse2004Content.  # noqa: E501

        is the remote connection established?  # noqa: E501

        :return: The remote_connection_established of this InlineResponse2004Content.  # noqa: E501
        :rtype: bool
        """
        return self._remote_connection_established

    @remote_connection_established.setter
    def remote_connection_established(self, remote_connection_established):
        """Sets the remote_connection_established of this InlineResponse2004Content.

        is the remote connection established?  # noqa: E501

        :param remote_connection_established: The remote_connection_established of this InlineResponse2004Content.  # noqa: E501
        :type remote_connection_established: bool
        """

        self._remote_connection_established = remote_connection_established

    @property
    def supports_zone_keypads(self):
        """Gets the supports_zone_keypads of this InlineResponse2004Content.  # noqa: E501

        This property will be true if the hub was published in Design Studio 2.0 in an installation containing devices that all have 1.15 firmware.  This signifies that a keypad's buttons can be configured to control independent zones and are not restricted to controlling the same set of groups.  # noqa: E501

        :return: The supports_zone_keypads of this InlineResponse2004Content.  # noqa: E501
        :rtype: bool
        """
        return self._supports_zone_keypads

    @supports_zone_keypads.setter
    def supports_zone_keypads(self, supports_zone_keypads):
        """Sets the supports_zone_keypads of this InlineResponse2004Content.

        This property will be true if the hub was published in Design Studio 2.0 in an installation containing devices that all have 1.15 firmware.  This signifies that a keypad's buttons can be configured to control independent zones and are not restricted to controlling the same set of groups.  # noqa: E501

        :param supports_zone_keypads: The supports_zone_keypads of this InlineResponse2004Content.  # noqa: E501
        :type supports_zone_keypads: bool
        """

        self._supports_zone_keypads = supports_zone_keypads

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2004Content):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2004Content):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from aioketraapi.api.group_operations_api import GroupOperationsApi
from aioketraapi.api.hub_operations_api import HubOperationsApi
from aioketraapi.api.keypad_operations_api import KeypadOperationsApi
from aioketraapi.api.lamp_operations_api import LampOperationsApi
from aioketraapi.api.scene_operations_api import SceneOperationsApi
